@@ -10,10 +10,16 @@ class Client(gateway.GatewayClient):
     def join_attribute_paths(*paths):
         return '.'.join([path for path in paths if path != ''])
 
-    def connect(self):
+    def connect(self, timeout: float = 10.0):
         if not self.connected:
             self.start(wait=False)
-            time.sleep(1)
+
+            start_time = time.time()
+            while not self.connected:
+                if time.time() - start_time > timeout:
+                    raise errors.ConnectionError(f'Timeout while waiting for client to connect')
+
+                time.sleep(0.01)
 
     def get_instance(self, instance_name, read_only: bool = False) -> Any:
         if not read_only:
