@@ -133,6 +133,9 @@ class Server(gateway.GatewayClient):
     async def _on_start(self):
         await self._register_gateway_instances(self.instances)
 
+    async def _on_stop(self):
+        self.instances = {}
+
     async def _register_gateway_instances(self, instances: Dict[str, Instance]):
         instance_data = [(instance.name, instance.group) for name, instance in instances.items()]
         await self.websocket_connection.send_request(messages.Method.REGISTER, instance_data)
@@ -140,6 +143,9 @@ class Server(gateway.GatewayClient):
     def register(self, name: str, instance: Any, group: Optional[str] = None) -> Any:
         self.logger.info(f'Registering instance: {name}')
 
+        if name is None or name == '':
+            raise errors.InvalidInstanceError(f'Cannot register instance with name: {name}')
+
         if name in self.instances:
             raise errors.InstanceAlreadyRegisteredError(f'Instance already registered with name: {name}')
 
@@ -150,6 +156,10 @@ class Server(gateway.GatewayClient):
 
         return instance
 
+    def deregister(self, name: str) -> Any:
+        self.logger.info(f'Deregistering instance: {name}')
+        self.websocket_connection.send_request_sync(messages.Method.DEREGISTER, [name])
+
     def _get_instance(self, instance_name: Union[type, str]) -> Instance:
         try:
             if isclass(instance_name):
